==> candyshop-0.1.1.tar.gz: candyshop-0.1.1/candyshop/__init__.py <==
# -*- coding: utf-8 -*-
#
#   This file is part of Odoo Candyshop
#   Copyright (C) 2016, Odoo Candyshop Developers
#   All rights reserved.
#
#   Please refer to AUTHORS.md for a complete list of Copyright
#   holders.
#
#   Odoo Candyshop is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published
#   by the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   Odoo Candyshop is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
``candyshop`` is just pure art.

Odoo Candyshop is a package that serves as a processor of the information
contained in Odoo Modules. It's primarily aimed at making reports of missing
dependencies in an Odoo Environment.

It has abstractions that represent Odoo Modules and virtual Odoo Enviroments,
as well as functions to resolve dependency trees.
"""

__author__ = 'Luis Alejandro Martínez Faneyth'
__email__ = 'luis@huntingbears.com.ve'
__version__ = '0.1.1'
__url__ = 'https://github.com/LuisAlejandro/odoo-candyshop'
__description__ = ('Odoo Candyshop is a helper to determine if all your '
                   'dependencies are declared properly.')

==> candyshop-0.1.3.tar.gz: candyshop-0.1.3/candyshop/__init__.py <==
# -*- coding: utf-8 -*-
#
#   This file is part of Candyshop
#   Copyright (C) 2016, Candyshop Developers
#   All rights reserved.
#
#   Please refer to AUTHORS.md for a complete list of Copyright
#   holders.
#
#   Candyshop is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published
#   by the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   Candyshop is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
``candyshop`` is just pure art.

Candyshop is a package that serves as a processor of the information
contained in Odoo Modules. It's primarily aimed at making reports of missing
dependencies in an Odoo Environment.

It has abstractions that represent Odoo Modules and virtual Odoo Enviroments,
as well as functions to resolve dependency trees.
"""

__author__ = 'Luis Alejandro Martínez Faneyth'
__email__ = 'luis@huntingbears.com.ve'
__version__ = '0.1.3'
__url__ = 'https://github.com/LuisAlejandro/candyshop'
__description__ = ('Candyshop is a helper to determine if all your '
                   'dependencies are declared properly.')
